@@ -1,22 +1,19 @@
-#!/usr/local/bin/perl -w
-
 # News.pm
 # Copyright (c) 1998 by Martin Thurn
-# $Id: News.pm,v 1.8 1998/08/21 00:03:57 johnh Exp $
-
-
-package WWW::Search::Infoseek::News;
+# $Id: News.pm,v 1.9 1999/06/30 15:09:12 mthurn Exp $
 
 =head1 NAME
 
 WWW::Search::Infoseek::News - class for Infoseek News searching
 
-
 =head1 SYNOPSIS
-    
-    require WWW::Search;
-    $search = new WWW::Search('Infoseek::News');
 
+  require WWW::Search;
+  $search = new WWW::Search('Infoseek::News');
+  my $sQuery = WWW::Search::escape_query("plane crash airline disaster");
+  $oSearch->native_query($sQuery);
+  while (my $oResult = $oSearch->next_result())
+    { print $oResult->url, "\n"; }
 
 =head1 DESCRIPTION
 
@@ -28,33 +25,34 @@ F<http://www.infoseek.com>.
 This class exports no public interface; all interaction should
 be done through WWW::Search objects.
 
-
 =head1 TESTING
 
-This module adheres to the WWW::Search test harness.  Test cases are:
-
-  'mrfglbqnx NoSuchWord' --> no hits
-  'Star Wars'            -->  5 hits on one page
-  'Hawaii'               --> 62 hits on three pages
-
+This module adheres to the C<WWW::Search> test suite mechanism. 
+See the value of $TEST_CASES below.
 
 =head1 AUTHOR
 
 C<WWW::Search::Infoseek::News> 
 was written by Martin Thurn <MartinThurn@iname.com> 
 
-
 =cut
 
 #####################################################################
 
+package WWW::Search::Infoseek::News;
+
+require WWW::Search::Infoseek;
 require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search::Infoseek Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$VERSION = '1.09';
 
-use WWW::Search::Infoseek;
+$MAINTAINER = 'Martin Thurn <MartinThurn@iname.com>';
+$TEST_CASES = <<"ENDTESTCASES";
+&test('Infoseek::News', '$MAINTAINER', 'zero', \$bogus_query, \$TEST_BY_COUNTING, 0);
+&test('Infoseek::News', '$MAINTAINER', 'multi', 'pris'.'on* AND esca'.'pe*', \$TEST_GREATER_THAN, 2);
+ENDTESTCASES
 
 # private
 sub native_setup_search
