@@ -1,18 +1,13 @@
-#!/usr/local/bin/perl -w
-
 # Web.pm
 # Copyright (c) 1998 by Martin Thurn
-# $Id: Web.pm,v 1.7 1998/08/21 00:03:57 johnh Exp $
-
-package WWW::Search::Infoseek::Web;
+# $Id: Web.pm,v 1.10 1999/06/30 15:35:19 mthurn Exp $
 
 =head1 NAME
 
 WWW::Search::Infoseek::Web - class for Infoseek Web searching
 
-
 =head1 SYNOPSIS
-    
+
   use WWW::Search;
   my $oSearch = new WWW::Search('Infoseek::Web');
   my $sQuery = WWW::Search::escape_query("+sushi restaurant +Columbus Ohio");
@@ -20,7 +15,6 @@ WWW::Search::Infoseek::Web - class for Infoseek Web searching
   while (my $oResult = $oSearch->next_result())
     { print $oResult->url, "\n"; }
 
-
 =head1 DESCRIPTION
 
 This class implements the Infoseek Web search
@@ -31,31 +25,34 @@ F<http://www.infoseek.com>.
 This class exports no public interface; all interaction should
 be done through WWW::Search objects.
 
-
 =head1 TESTING
 
-This module adheres to the WWW::Search test harness.  
-
-  'mrfglbqnx NoSuchWord'       --> no hits
-  'Martin Thurn AND Star Wars' --> 11 hits on one page
-  'Greedo AND collectible'     --> 38 hits on two pages
-
+This module adheres to the WWW::Search test mechanism.
+See $TEST_CASES below.
 
 =head1 AUTHOR
 
 C<WWW::Search::Infoseek::Web> 
 was written by Martin Thurn <MartinThurn@iname.com> 
 
-
 =cut
 
 #####################################################################
 
+package WWW::Search::Infoseek::Web;
+
 require Exporter;
 @EXPORT = qw();
 @EXPORT_OK = qw();
 @ISA = qw(WWW::Search::Infoseek Exporter);
-$VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$VERSION = '1.10';
+
+$MAINTAINER = 'Martin Thurn <MartinThurn@iname.com>';
+$TEST_CASES = <<"ENDTESTCASES";
+&test('Infoseek::Web', '$MAINTAINER', 'zero', \$bogus_query, \$TEST_BY_COUNTING, 0);
+&test('Infoseek::Web', '$MAINTAINER', 'one_page', 'Mar'.'tin Thurn AND St'.'ar Wa'.'rs', \$TEST_RANGE, 2,24);
+&test('Infoseek::Web', '$MAINTAINER', 'two_page', 'Gre'.'edo AND collecti'.'ble', \$TEST_GREATER_THAN, 25);
+ENDTESTCASES
 
 use WWW::Search::Infoseek;
 
